

- Don't do `return;' from an int-returning function.

- Casting int-returning function to void is not kernel-style.

Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/fs/fs-writeback.c |    8 ++++----
 25-akpm/fs/inode.c        |    2 +-
 2 files changed, 5 insertions(+), 5 deletions(-)

diff -puN fs/fs-writeback.c~bug-on-error-handlings-in-ext3-under-i-o-failure-fix fs/fs-writeback.c
--- 25/fs/fs-writeback.c~bug-on-error-handlings-in-ext3-under-i-o-failure-fix	2005-01-04 18:09:36.887202688 -0800
+++ 25-akpm/fs/fs-writeback.c	2005-01-04 18:09:58.889857776 -0800
@@ -559,22 +559,22 @@ void sync_inodes(int wait)
  
 int write_inode_now(struct inode *inode, int sync)
 {
-	int err = 0;
+	int ret;
 	struct writeback_control wbc = {
 		.nr_to_write = LONG_MAX,
 		.sync_mode = WB_SYNC_ALL,
 	};
 
 	if (inode->i_mapping->backing_dev_info->memory_backed)
-		return;
+		return 0;
 
 	might_sleep();
 	spin_lock(&inode_lock);
-	err = __writeback_single_inode(inode, &wbc);
+	ret = __writeback_single_inode(inode, &wbc);
 	spin_unlock(&inode_lock);
 	if (sync)
 		wait_on_inode(inode);
-	return err;
+	return ret;
 }
 EXPORT_SYMBOL(write_inode_now);
 
diff -puN fs/inode.c~bug-on-error-handlings-in-ext3-under-i-o-failure-fix fs/inode.c
--- 25/fs/inode.c~bug-on-error-handlings-in-ext3-under-i-o-failure-fix	2005-01-04 18:10:31.294931456 -0800
+++ 25-akpm/fs/inode.c	2005-01-04 18:10:43.103136336 -0800
@@ -1035,7 +1035,7 @@ static void generic_forget_inode(struct 
 		spin_unlock(&inode_lock);
 		if (!sb || (sb->s_flags & MS_ACTIVE))
 			return;
-		(void) write_inode_now(inode, 1);
+		write_inode_now(inode, 1);
 		spin_lock(&inode_lock);
 		inodes_stat.nr_unused--;
 		hlist_del_init(&inode->i_hash);
_
